---
title: <span class="badge object-type-enum"></span> HeatmapColorScale
---
# <span class="badge object-type-enum"></span> HeatmapColorScale

Controls the color scale of the heatmap

## Definition

```python
class HeatmapColorScale(enum.StrEnum):
    """
    Controls the color scale of the heatmap
    """

    LINEAR = "linear"
    EXPONENTIAL = "exponential"
```
